Skip to contents

Collapse Wallow Episodes

Usage

collapse_wallow_episodes(df)

Arguments

df

a data frame of wallow image data, read in with read_image_data().

Value

a data frame with wallow image data collapsed into 1 row per episode, and summary information about each episode (e.g. duration, number of triggers, total count, social and wallow behaviour, ...).